@@ -23,6 +23,9 @@ class Unsafe(
         self.admin_finder_queue = Queue()
         self.file_manager_queue = Queue()
         self.cloudflare_subdomain_bypasser = Queue()
+        self.zip_cracker_queue = Queue()
         self.admin_finder_founded = []
         self.file_manager_founded = []
         self.subdomain_bypassed = {}
+        self.zip_threads = []
+        self.zip_password_founded = []
