@@ -243,7 +243,7 @@ class BruteForcer:
             i.join()
         return self.subdomain_bypassed
 
-    def _crack_zip_handler(password: str, zip_file: ZipFile):
+    def _crack_zip_handler(self, password: str, zip_file: ZipFile):
         idx = 0
         try:
             zip_file.extractall(pwd=password)
@@ -255,7 +255,7 @@ class BruteForcer:
         zip_object = ZipFile(zip_path)
         while not password_list.empty():
             i = password_list.get()
-            if self._crack_zip_handler(password=i, zip_path=zip_object):
+            if self._crack_zip_handler(password=i, zip_file=zip_object):
                 self.zip_password_founded.append(i)
                 for k in self.zip_threads:
                     k._stop()
